/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.common.formdata;

import java.util.Map;
import java.util.UUID;

public class AntragstellerTestFactory {

	public static final String ANREDE = "Herr";

	public static final String GEBIET_BEZEICHNUNG_KEY = "GebietBEZEICHNUNG";
	public static final String GEBIET_BEZEICHNUNG_VALUE = "Schleswig";

	public static final String SUB_PERSOENLICHE_EIGNUNG = "persoenlicheEignung";
	public static final String SUB_VERBOTENE_VEREINIGUNG_KEY = "MitgliedschaftInVerboternerVereinigung";
	public static final String SUB_VERBOTENE_VEREINIGUNG_VALUE = "true";

	public static final String VORNAME = "Theo";
	public static final String NACHNAME = "Test";
	public static final String GEBURTSNAME = "Toast";
	public static final String GEBURTSDATUM = "30.8.1955";
	public static final String GEBURTSORT = "Mülheim an der Ruhr";
	public static final String EMAIL = "schneider@helgeschneider.local";
	public static final String STRASSE = "Musterstraße";
	public static final String HAUSNUMMER = "1";
	public static final String PLZ = "12345";
	public static final String ORT = "Musterstadt";
	public static final String TELEFON = "+ 0176 888 666 222XX";
	public static final String POSTFACH_ID = UUID.randomUUID().toString();

	public static Antragsteller create() {
		return createBuilder().build();
	}

	public static Antragsteller.AntragstellerBuilder createBuilder() {
		return Antragsteller.builder()
				.anrede(ANREDE)
				.vorname(VORNAME)
				.nachname(NACHNAME)
				.geburtsname(GEBURTSNAME)
				.geburtsdatum(GEBURTSDATUM)
				.geburtsort(GEBURTSORT)
				.email(EMAIL)
				.telefon(TELEFON)
				.strasse(STRASSE)
				.hausnummer(HAUSNUMMER)
				.plz(PLZ)
				.ort(ORT)
				.postfachId(POSTFACH_ID)
				.data(Map.of(GEBIET_BEZEICHNUNG_KEY, GEBIET_BEZEICHNUNG_VALUE,
						SUB_PERSOENLICHE_EIGNUNG,
						Map.of(SUB_VERBOTENE_VEREINIGUNG_KEY, SUB_VERBOTENE_VEREINIGUNG_VALUE)));
	}
}
