/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.semantik.enginebased.afm;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.util.Collections;
import java.util.List;
import java.util.Map;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.springframework.test.util.ReflectionTestUtils;

import de.ozgcloud.eingang.common.formdata.FormData;
import de.ozgcloud.eingang.semantik.enginebased.EngineBasedMapper;
import de.ozgcloud.eingang.semantik.enginebased.afm.AfmAntragstellerMapper;
import de.ozgcloud.eingang.semantik.enginebased.afm.AfmEngineBasedAdapter;
import de.ozgcloud.eingang.semantik.enginebased.afm.AfmEngineBasedMapper;

class AfmEngineBasedAdapterTest {

	@Spy
	@InjectMocks
	private AfmEngineBasedAdapter adapter;
	@Spy
	private List<EngineBasedMapper> mappers;
	@Mock
	private AfmEngineBasedMapper mapper;

	@DisplayName("Parse form data")
	@Nested
	class TestParseFromData {

		private final Map<String, Object> formDataMap = Map.of(AfmAntragstellerMapper.POSTFACH_ID, "postfachIdValue");
		private final FormData formData = FormData.builder().formData(formDataMap).build();

		@BeforeEach
		void mockMappers() {
			ReflectionTestUtils.setField(adapter, "mappers", Collections.singletonList(mapper));
		}

		@BeforeEach
		void mockEngineBasedMapper() {
			when(mapper.parseFormData(any())).thenReturn(formData);
		}

		@Test
		void shouldCallMappers() {
			adapter.parseFormData(formData);

			verify(mapper).parseFormData(formData);
		}

		@Test
		void shouldRemoveProcessedData() {
			adapter.parseFormData(formData);

			verify(adapter).removeProcessedData(formData);
		}

		@Test
		void shouldRemovePostfachId() {
			var mappedFormData = adapter.parseFormData(formData);

			assertThat(mappedFormData.getFormData()).doesNotContainKey(AfmAntragstellerMapper.POSTFACH_ID);
		}
	}
}
